# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import empire_platform_api_public_client
from empire_platform_api_public_client.api.transmission_right_api import TransmissionRightApi  # noqa: E501
from empire_platform_api_public_client.rest import ApiException


class TestTransmissionRightApi(unittest.TestCase):
    """TransmissionRightApi unit test stubs"""

    def setUp(self):
        self.api = empire_platform_api_public_client.api.transmission_right_api.TransmissionRightApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_transmission_rights_overview(self):
        """Test case for get_transmission_rights_overview

        """
        pass


if __name__ == '__main__':
    unittest.main()
