# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.bidding_configuration_per_direction import BiddingConfigurationPerDirection  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestBiddingConfigurationPerDirection(unittest.TestCase):
    """BiddingConfigurationPerDirection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BiddingConfigurationPerDirection
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BiddingConfigurationPerDirection`
        """
        model = empire_platform_api_public_client.models.bidding_configuration_per_direction.BiddingConfigurationPerDirection()  # noqa: E501
        if include_optional :
            return BiddingConfigurationPerDirection(
                maximum_bid_capacity = 56, 
                warning_bid_price = 1.337, 
                maximum_bid_price = 1.337
            )
        else :
            return BiddingConfigurationPerDirection(
        )
        """

    def testBiddingConfigurationPerDirection(self):
        """Test BiddingConfigurationPerDirection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
