# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.secondary_market_return_request import SecondaryMarketReturnRequest  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestSecondaryMarketReturnRequest(unittest.TestCase):
    """SecondaryMarketReturnRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecondaryMarketReturnRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecondaryMarketReturnRequest`
        """
        model = empire_platform_api_public_client.models.secondary_market_return_request.SecondaryMarketReturnRequest()  # noqa: E501
        if include_optional :
            return SecondaryMarketReturnRequest(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                source_auction = empire_platform_api_public_client.models.source_auction_display_data.SourceAuctionDisplayData(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    display_id = 'BDL-NL-GB-E-BASE---220305-01', ), 
                return_auction = empire_platform_api_public_client.models.return_auction.ReturnAuction(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                    direction = 'GB_NL', 
                    delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                        from_mtu_start = '2022-01-04T10:00Z', 
                        to_mtu_end = '2022-01-04T11:00Z', ), 
                    status = 'CREATED', ), 
                returned_capacity = 56, 
                successfully_allocated_capacity = 56, 
                price = 1.337, 
                status = 'PENDING'
            )
        else :
            return SecondaryMarketReturnRequest(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                source_auction = empire_platform_api_public_client.models.source_auction_display_data.SourceAuctionDisplayData(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    display_id = 'BDL-NL-GB-E-BASE---220305-01', ),
                return_auction = empire_platform_api_public_client.models.return_auction.ReturnAuction(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                    direction = 'GB_NL', 
                    delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                        from_mtu_start = '2022-01-04T10:00Z', 
                        to_mtu_end = '2022-01-04T11:00Z', ), 
                    status = 'CREATED', ),
                returned_capacity = 56,
                status = 'PENDING',
        )
        """

    def testSecondaryMarketReturnRequest(self):
        """Test SecondaryMarketReturnRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
