# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data import ParticipantDashboardInterconnectorCapacityGraphData  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestParticipantDashboardInterconnectorCapacityGraphData(unittest.TestCase):
    """ParticipantDashboardInterconnectorCapacityGraphData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ParticipantDashboardInterconnectorCapacityGraphData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardInterconnectorCapacityGraphData`
        """
        model = empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data.ParticipantDashboardInterconnectorCapacityGraphData()  # noqa: E501
        if include_optional :
            return ParticipantDashboardInterconnectorCapacityGraphData(
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner(
                        mtu = '2022-01-04T10:00Z', 
                        values = [
                            empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_values_inner.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner_values_inner(
                                direction = 'GB_NL', 
                                ntc = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_netted_nominations.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner_nettedNominations(
                            direction = 'GB_NL', 
                            flow = 56, ), )
                    ]
            )
        else :
            return ParticipantDashboardInterconnectorCapacityGraphData(
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner(
                        mtu = '2022-01-04T10:00Z', 
                        values = [
                            empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_values_inner.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner_values_inner(
                                direction = 'GB_NL', 
                                ntc = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_netted_nominations.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner_nettedNominations(
                            direction = 'GB_NL', 
                            flow = 56, ), )
                    ],
        )
        """

    def testParticipantDashboardInterconnectorCapacityGraphData(self):
        """Test ParticipantDashboardInterconnectorCapacityGraphData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
