# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class UserRole(str, Enum):
    """
    UserRole
    """

    """
    allowed enum values
    """
    ICO_ADMIN_BDL = 'ICO_ADMIN_BDL'
    ICO_ADMIN_HELPDESK = 'ICO_ADMIN_HELPDESK'
    ICO_ONCALL_MGR = 'ICO_ONCALL_MGR'
    ICO_ONCALL_MGR_AUCT = 'ICO_ONCALL_MGR_AUCT'
    ICO_ONCALL_MGR_FIN = 'ICO_ONCALL_MGR_FIN'
    ICO_ONCALL_ANALYST = 'ICO_ONCALL_ANALYST'
    ICO_ONCALL_ANALYIST_AUCT = 'ICO_ONCALL_ANALYIST_AUCT'
    ICO_ONCALL_TRAINING = 'ICO_ONCALL_TRAINING'
    ICO_FINANCE = 'ICO_FINANCE'
    ICO_VIEW = 'ICO_VIEW'
    ICO_VIEW_AUCT = 'ICO_VIEW_AUCT'
    TSO_USER = 'TSO_USER'
    PART_ADMIN = 'PART_ADMIN'
    PART_TRADER = 'PART_TRADER'
    PART_NOMINATOR = 'PART_NOMINATOR'
    PART_NOM_TRADER = 'PART_NOM_TRADER'
    PART_VIEW = 'PART_VIEW'

    @classmethod
    def from_json(cls, json_str: str) -> UserRole:
        """Create an instance of UserRole from a JSON string"""
        return UserRole(json.loads(json_str))


