# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuctionProductType(str, Enum):
    """
    Auction product type. Each product type is part of a larger group, shown by the prefix of each value: - `LT_*` - Long Term - `DA_*` - Day Ahead - `ID_*` - Intra Day 
    """

    """
    allowed enum values
    """
    LT_EXPLICIT_MULTI_ANNUAL = 'LT_EXPLICIT_MULTI_ANNUAL'
    LT_EXPLICIT_ANNUAL = 'LT_EXPLICIT_ANNUAL'
    LT_EXPLICIT_SEASONAL = 'LT_EXPLICIT_SEASONAL'
    LT_EXPLICIT_QUARTERLY = 'LT_EXPLICIT_QUARTERLY'
    LT_EXPLICIT_MONTHLY = 'LT_EXPLICIT_MONTHLY'
    LT_EXPLICIT_MULTIDAY = 'LT_EXPLICIT_MULTIDAY'
    LT_EXPLICIT_WEEKLY = 'LT_EXPLICIT_WEEKLY'
    LT_EXPLICIT_WEEKEND = 'LT_EXPLICIT_WEEKEND'
    LT_EXPLICIT_LONG_WEEKEND = 'LT_EXPLICIT_LONG_WEEKEND'
    DA_EXPLICIT_DA = 'DA_EXPLICIT_DA'
    ID_EXPLICIT_ID_1 = 'ID_EXPLICIT_ID_1'
    ID_EXPLICIT_ID_2 = 'ID_EXPLICIT_ID_2'
    ID_EXPLICIT_ID_3 = 'ID_EXPLICIT_ID_3'
    ID_EXPLICIT_ID_4 = 'ID_EXPLICIT_ID_4'

    @classmethod
    def from_json(cls, json_str: str) -> AuctionProductType:
        """Create an instance of AuctionProductType from a JSON string"""
        return AuctionProductType(json.loads(json_str))


