# coding: utf-8

# flake8: noqa
"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


# import models into model package
from empire_platform_api_public_client.models.address import Address
from empire_platform_api_public_client.models.aggregated_allocated_auction import AggregatedAllocatedAuction
from empire_platform_api_public_client.models.aggregated_nomination_options import AggregatedNominationOptions
from empire_platform_api_public_client.models.aggregated_nomination_options_nominee_participants_inner import AggregatedNominationOptionsNomineeParticipantsInner
from empire_platform_api_public_client.models.aggregated_nomination_type import AggregatedNominationType
from empire_platform_api_public_client.models.aggregated_nominations import AggregatedNominations
from empire_platform_api_public_client.models.aggregated_nominations_mns_or_gb import AggregatedNominationsMnsOrGb
from empire_platform_api_public_client.models.aggregated_nominations_mns_or_gb_mtus_inner import AggregatedNominationsMnsOrGbMtusInner
from empire_platform_api_public_client.models.aggregated_nominations_mtu_netted_nominations import AggregatedNominationsMtuNettedNominations
from empire_platform_api_public_client.models.aggregated_nominations_mtu_value import AggregatedNominationsMtuValue
from empire_platform_api_public_client.models.aggregated_nominations_nl import AggregatedNominationsNl
from empire_platform_api_public_client.models.aggregated_nominations_nl_mtus_inner import AggregatedNominationsNlMtusInner
from empire_platform_api_public_client.models.aggregated_nominations_nl_mtus_inner_eprogram_values import AggregatedNominationsNlMtusInnerEprogramValues
from empire_platform_api_public_client.models.allocated_auction import AllocatedAuction
from empire_platform_api_public_client.models.allocated_auction_batch import AllocatedAuctionBatch
from empire_platform_api_public_client.models.allocated_auction_sort_by import AllocatedAuctionSortBy
from empire_platform_api_public_client.models.api_key import ApiKey
from empire_platform_api_public_client.models.attachment import Attachment
from empire_platform_api_public_client.models.auction import Auction
from empire_platform_api_public_client.models.auction_allocation_resolution import AuctionAllocationResolution
from empire_platform_api_public_client.models.auction_batch import AuctionBatch
from empire_platform_api_public_client.models.auction_bid_participant import AuctionBidParticipant
from empire_platform_api_public_client.models.auction_bid_status import AuctionBidStatus
from empire_platform_api_public_client.models.auction_bidding_configuration import AuctionBiddingConfiguration
from empire_platform_api_public_client.models.auction_bidding_mode import AuctionBiddingMode
from empire_platform_api_public_client.models.auction_intra_day_product_type import AuctionIntraDayProductType
from empire_platform_api_public_client.models.auction_process_steps_absolute import AuctionProcessStepsAbsolute
from empire_platform_api_public_client.models.auction_product_type import AuctionProductType
from empire_platform_api_public_client.models.auction_reduction_period import AuctionReductionPeriod
from empire_platform_api_public_client.models.auction_result_congestion_rent import AuctionResultCongestionRent
from empire_platform_api_public_client.models.auction_result_participant import AuctionResultParticipant
from empire_platform_api_public_client.models.auction_sort_by import AuctionSortBy
from empire_platform_api_public_client.models.auction_status import AuctionStatus
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.audit_log import AuditLog
from empire_platform_api_public_client.models.audit_log_api_key import AuditLogApiKey
from empire_platform_api_public_client.models.audit_log_batch import AuditLogBatch
from empire_platform_api_public_client.models.audit_log_domain import AuditLogDomain
from empire_platform_api_public_client.models.audit_log_payload import AuditLogPayload
from empire_platform_api_public_client.models.audit_log_sort_by import AuditLogSortBy
from empire_platform_api_public_client.models.audit_log_status import AuditLogStatus
from empire_platform_api_public_client.models.audit_log_type import AuditLogType
from empire_platform_api_public_client.models.audit_log_user import AuditLogUser
from empire_platform_api_public_client.models.audit_log_user_organisation import AuditLogUserOrganisation
from empire_platform_api_public_client.models.bid_value import BidValue
from empire_platform_api_public_client.models.bidding_configuration import BiddingConfiguration
from empire_platform_api_public_client.models.bidding_configuration_per_direction import BiddingConfigurationPerDirection
from empire_platform_api_public_client.models.bidding_configuration_secondary_market_notices import BiddingConfigurationSecondaryMarketNotices
from empire_platform_api_public_client.models.bidding_configuration_values_inner import BiddingConfigurationValuesInner
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.border_direction_with_both import BorderDirectionWithBoth
from empire_platform_api_public_client.models.border_direction_with_both_and_none import BorderDirectionWithBothAndNone
from empire_platform_api_public_client.models.buy_now_day_ahead_offer_sort_by import BuyNowDayAheadOfferSortBy
from empire_platform_api_public_client.models.buy_now_offer import BuyNowOffer
from empire_platform_api_public_client.models.buy_now_offer_mtus_inner import BuyNowOfferMtusInner
from empire_platform_api_public_client.models.buy_now_offer_status import BuyNowOfferStatus
from empire_platform_api_public_client.models.create_api_key_request import CreateApiKeyRequest
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request import CreateDayAheadOrIntraDayDefaultBidRequest
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner import CreateDayAheadOrIntraDayDefaultBidRequestBidsInner
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner_mtus_inner import CreateDayAheadOrIntraDayDefaultBidRequestBidsInnerMtusInner
from empire_platform_api_public_client.models.create_default_nomination_request import CreateDefaultNominationRequest
from empire_platform_api_public_client.models.create_long_term_default_bid_request import CreateLongTermDefaultBidRequest
from empire_platform_api_public_client.models.create_organisation_document_request import CreateOrganisationDocumentRequest
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_noticeboard_entry import CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_noticeboard_response import CreateSecondaryMarketDayAheadOrIntraDayNoticeboardResponse
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_transfer_request import CreateSecondaryMarketDayAheadOrIntraDayTransferRequest
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_transfer_request_mtus_inner import CreateSecondaryMarketDayAheadOrIntraDayTransferRequestMtusInner
from empire_platform_api_public_client.models.create_secondary_market_long_term_noticeboard_entry import CreateSecondaryMarketLongTermNoticeboardEntry
from empire_platform_api_public_client.models.create_secondary_market_long_term_noticeboard_response import CreateSecondaryMarketLongTermNoticeboardResponse
from empire_platform_api_public_client.models.create_secondary_market_long_term_transfer_request import CreateSecondaryMarketLongTermTransferRequest
from empire_platform_api_public_client.models.create_secondary_market_return_request import CreateSecondaryMarketReturnRequest
from empire_platform_api_public_client.models.created_api_key import CreatedApiKey
from empire_platform_api_public_client.models.created_default_bid import CreatedDefaultBid
from empire_platform_api_public_client.models.created_default_nomination import CreatedDefaultNomination
from empire_platform_api_public_client.models.created_organisation_document import CreatedOrganisationDocument
from empire_platform_api_public_client.models.created_secondary_market_day_ahead_or_intra_day_noticeboard_entry import CreatedSecondaryMarketDayAheadOrIntraDayNoticeboardEntry
from empire_platform_api_public_client.models.created_secondary_market_day_ahead_or_intra_day_noticeboard_response import CreatedSecondaryMarketDayAheadOrIntraDayNoticeboardResponse
from empire_platform_api_public_client.models.created_secondary_market_day_ahead_or_intra_day_transfer_request import CreatedSecondaryMarketDayAheadOrIntraDayTransferRequest
from empire_platform_api_public_client.models.created_secondary_market_long_term_noticeboard_entry import CreatedSecondaryMarketLongTermNoticeboardEntry
from empire_platform_api_public_client.models.created_secondary_market_long_term_noticeboard_response import CreatedSecondaryMarketLongTermNoticeboardResponse
from empire_platform_api_public_client.models.created_secondary_market_long_term_transfer_request import CreatedSecondaryMarketLongTermTransferRequest
from empire_platform_api_public_client.models.created_secondary_market_return_request_identifier import CreatedSecondaryMarketReturnRequestIdentifier
from empire_platform_api_public_client.models.dashboard_next_nomination_gate import DashboardNextNominationGate
from empire_platform_api_public_client.models.dashboard_next_nomination_gate_window import DashboardNextNominationGateWindow
from empire_platform_api_public_client.models.dashboard_next_nomination_window_status import DashboardNextNominationWindowStatus
from empire_platform_api_public_client.models.date_period import DatePeriod
from empire_platform_api_public_client.models.date_time_period import DateTimePeriod
from empire_platform_api_public_client.models.day_ahead_auction import DayAheadAuction
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group import DayAheadOrIntraDayAuctionBidGroup
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner import DayAheadOrIntraDayAuctionBidGroupBidsInner
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner_bid import DayAheadOrIntraDayAuctionBidGroupBidsInnerBid
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner_bid_results import DayAheadOrIntraDayAuctionBidGroupBidsInnerBidResults
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result import DayAheadOrIntraDayAuctionBidGroupResult
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result_batch import DayAheadOrIntraDayAuctionBidGroupResultBatch
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result_bids_inner import DayAheadOrIntraDayAuctionBidGroupResultBidsInner
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result_bids_inner_bid import DayAheadOrIntraDayAuctionBidGroupResultBidsInnerBid
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu import DayAheadOrIntraDayAuctionMtu
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu_results import DayAheadOrIntraDayAuctionMtuResults
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu_results_bids_inner import DayAheadOrIntraDayAuctionMtuResultsBidsInner
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_participant_results import DayAheadOrIntraDayAuctionParticipantResults
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_participant_results_mtus_inner import DayAheadOrIntraDayAuctionParticipantResultsMtusInner
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_participant_results_mtus_inner_value import DayAheadOrIntraDayAuctionParticipantResultsMtusInnerValue
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results import DayAheadOrIntraDayAuctionResults
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results_mtu import DayAheadOrIntraDayAuctionResultsMtu
from empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid import DayAheadOrIntraDayDefaultBid
from empire_platform_api_public_client.models.default_bid import DefaultBid
from empire_platform_api_public_client.models.default_bid_batch import DefaultBidBatch
from empire_platform_api_public_client.models.default_bid_options import DefaultBidOptions
from empire_platform_api_public_client.models.default_bid_sort_by import DefaultBidSortBy
from empire_platform_api_public_client.models.default_bid_status import DefaultBidStatus
from empire_platform_api_public_client.models.default_nomination import DefaultNomination
from empire_platform_api_public_client.models.default_nomination_batch import DefaultNominationBatch
from empire_platform_api_public_client.models.default_nomination_declaration_type import DefaultNominationDeclarationType
from empire_platform_api_public_client.models.default_nomination_details import DefaultNominationDetails
from empire_platform_api_public_client.models.default_nomination_mtu import DefaultNominationMtu
from empire_platform_api_public_client.models.default_nomination_options import DefaultNominationOptions
from empire_platform_api_public_client.models.default_nomination_sort_by import DefaultNominationSortBy
from empire_platform_api_public_client.models.default_nomination_status import DefaultNominationStatus
from empire_platform_api_public_client.models.error_code import ErrorCode
from empire_platform_api_public_client.models.error_response import ErrorResponse
from empire_platform_api_public_client.models.finance_information import FinanceInformation
from empire_platform_api_public_client.models.finance_information_bank_deposits_inner import FinanceInformationBankDepositsInner
from empire_platform_api_public_client.models.finance_information_letter_of_credits_inner import FinanceInformationLetterOfCreditsInner
from empire_platform_api_public_client.models.finance_information_lockable_amount import FinanceInformationLockableAmount
from empire_platform_api_public_client.models.finance_information_lockable_date import FinanceInformationLockableDate
from empire_platform_api_public_client.models.finance_information_lockable_period import FinanceInformationLockablePeriod
from empire_platform_api_public_client.models.finance_information_market_vat_details import FinanceInformationMarketVatDetails
from empire_platform_api_public_client.models.finance_information_sage_settings import FinanceInformationSageSettings
from empire_platform_api_public_client.models.intra_day_auction import IntraDayAuction
from empire_platform_api_public_client.models.invoice import Invoice
from empire_platform_api_public_client.models.invoice_action_type import InvoiceActionType
from empire_platform_api_public_client.models.invoice_batch import InvoiceBatch
from empire_platform_api_public_client.models.invoice_details import InvoiceDetails
from empire_platform_api_public_client.models.invoice_history import InvoiceHistory
from empire_platform_api_public_client.models.invoice_line_item import InvoiceLineItem
from empire_platform_api_public_client.models.invoice_participant_details import InvoiceParticipantDetails
from empire_platform_api_public_client.models.invoice_status import InvoiceStatus
from empire_platform_api_public_client.models.invoice_summary import InvoiceSummary
from empire_platform_api_public_client.models.invoice_vat_rate import InvoiceVatRate
from empire_platform_api_public_client.models.long_term_auction import LongTermAuction
from empire_platform_api_public_client.models.long_term_auction_bid import LongTermAuctionBid
from empire_platform_api_public_client.models.long_term_auction_bid_result import LongTermAuctionBidResult
from empire_platform_api_public_client.models.long_term_auction_bid_result_batch import LongTermAuctionBidResultBatch
from empire_platform_api_public_client.models.long_term_auction_bid_sort_by import LongTermAuctionBidSortBy
from empire_platform_api_public_client.models.long_term_auction_results import LongTermAuctionResults
from empire_platform_api_public_client.models.long_term_auction_results_allocated_capacity_inner import LongTermAuctionResultsAllocatedCapacityInner
from empire_platform_api_public_client.models.long_term_default_bid import LongTermDefaultBid
from empire_platform_api_public_client.models.long_term_offered_capacity import LongTermOfferedCapacity
from empire_platform_api_public_client.models.long_term_reserve_price import LongTermReservePrice
from empire_platform_api_public_client.models.long_term_reserve_price_steps_inner import LongTermReservePriceStepsInner
from empire_platform_api_public_client.models.manual_file_upload_request import ManualFileUploadRequest
from empire_platform_api_public_client.models.market import Market
from empire_platform_api_public_client.models.message import Message
from empire_platform_api_public_client.models.message_batch import MessageBatch
from empire_platform_api_public_client.models.message_category import MessageCategory
from empire_platform_api_public_client.models.message_sender import MessageSender
from empire_platform_api_public_client.models.message_severity import MessageSeverity
from empire_platform_api_public_client.models.message_sort_by import MessageSortBy
from empire_platform_api_public_client.models.message_type import MessageType
from empire_platform_api_public_client.models.mtu_period import MtuPeriod
from empire_platform_api_public_client.models.mtu_size import MtuSize
from empire_platform_api_public_client.models.mtu_size_per_auction_product_type import MtuSizePerAuctionProductType
from empire_platform_api_public_client.models.mtu_size_per_timescale import MtuSizePerTimescale
from empire_platform_api_public_client.models.nested_error import NestedError
from empire_platform_api_public_client.models.nomination_capacity_resolution import NominationCapacityResolution
from empire_platform_api_public_client.models.nomination_restriction_type import NominationRestrictionType
from empire_platform_api_public_client.models.noticeboard_entry_type import NoticeboardEntryType
from empire_platform_api_public_client.models.noticeboard_entry_type_with_both import NoticeboardEntryTypeWithBoth
from empire_platform_api_public_client.models.notification_preference import NotificationPreference
from empire_platform_api_public_client.models.notification_preference_with_sms import NotificationPreferenceWithSms
from empire_platform_api_public_client.models.ntc_overview_mtu_data import NtcOverviewMtuData
from empire_platform_api_public_client.models.offered_capacity_setup import OfferedCapacitySetup
from empire_platform_api_public_client.models.organisation import Organisation
from empire_platform_api_public_client.models.organisation_auth_method import OrganisationAuthMethod
from empire_platform_api_public_client.models.organisation_contact import OrganisationContact
from empire_platform_api_public_client.models.organisation_contact_information import OrganisationContactInformation
from empire_platform_api_public_client.models.organisation_document import OrganisationDocument
from empire_platform_api_public_client.models.organisation_document_batch import OrganisationDocumentBatch
from empire_platform_api_public_client.models.organisation_document_file_type import OrganisationDocumentFileType
from empire_platform_api_public_client.models.organisation_document_options import OrganisationDocumentOptions
from empire_platform_api_public_client.models.organisation_document_organisation import OrganisationDocumentOrganisation
from empire_platform_api_public_client.models.organisation_document_sort_by import OrganisationDocumentSortBy
from empire_platform_api_public_client.models.organisation_document_status import OrganisationDocumentStatus
from empire_platform_api_public_client.models.organisation_document_uploaded_by_user import OrganisationDocumentUploadedByUser
from empire_platform_api_public_client.models.organisation_document_user import OrganisationDocumentUser
from empire_platform_api_public_client.models.organisation_file_settings import OrganisationFileSettings
from empire_platform_api_public_client.models.organisation_market_settings import OrganisationMarketSettings
from empire_platform_api_public_client.models.organisation_market_settings_gb_nomination_settings import OrganisationMarketSettingsGbNominationSettings
from empire_platform_api_public_client.models.organisation_market_settings_nl_nomination_settings import OrganisationMarketSettingsNlNominationSettings
from empire_platform_api_public_client.models.organisation_status import OrganisationStatus
from empire_platform_api_public_client.models.organisation_type import OrganisationType
from empire_platform_api_public_client.models.organisation_user import OrganisationUser
from empire_platform_api_public_client.models.organisation_user_batch import OrganisationUserBatch
from empire_platform_api_public_client.models.organisation_user_sort_by import OrganisationUserSortBy
from empire_platform_api_public_client.models.other_party import OtherParty
from empire_platform_api_public_client.models.participant import Participant
from empire_platform_api_public_client.models.participant_dashboard_default_bids_and_nominations_data import ParticipantDashboardDefaultBidsAndNominationsData
from empire_platform_api_public_client.models.participant_dashboard_finance_overview_data import ParticipantDashboardFinanceOverviewData
from empire_platform_api_public_client.models.participant_dashboard_finance_overview_invoice import ParticipantDashboardFinanceOverviewInvoice
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data import ParticipantDashboardInterconnectorCapacityData
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus_inner import ParticipantDashboardInterconnectorCapacityDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus_inner_values_inner import ParticipantDashboardInterconnectorCapacityDataMtusInnerValuesInner
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data import ParticipantDashboardInterconnectorCapacityGraphData
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner import ParticipantDashboardInterconnectorCapacityGraphDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_netted_nominations import ParticipantDashboardInterconnectorCapacityGraphDataMtusInnerNettedNominations
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_values_inner import ParticipantDashboardInterconnectorCapacityGraphDataMtusInnerValuesInner
from empire_platform_api_public_client.models.participant_dashboard_messages import ParticipantDashboardMessages
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data import ParticipantDashboardNettedNominationsData
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_inner import ParticipantDashboardNettedNominationsDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_inner_aggregated_nominations_inner import ParticipantDashboardNettedNominationsDataMtusInnerAggregatedNominationsInner
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_inner_netted_nominations import ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations
from empire_platform_api_public_client.models.participant_dashboard_next_auction import ParticipantDashboardNextAuction
from empire_platform_api_public_client.models.participant_dashboard_next_auctions_and_nomination_gates import ParticipantDashboardNextAuctionsAndNominationGates
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data import ParticipantDashboardTransmissionRightsAndNominationsData
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus_inner import ParticipantDashboardTransmissionRightsAndNominationsDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus_inner_values_inner import ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus_inner_values_inner_nomination_restriction import ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInnerNominationRestriction
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data import ParticipantDashboardTransmissionRightsAndNominationsGraphData
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus_inner import ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus_inner_values_inner import ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtusInnerValuesInner
from empire_platform_api_public_client.models.participant_organisation_details import ParticipantOrganisationDetails
from empire_platform_api_public_client.models.participant_overview_data import ParticipantOverviewData
from empire_platform_api_public_client.models.participant_overview_data_contact_information import ParticipantOverviewDataContactInformation
from empire_platform_api_public_client.models.participant_overview_data_finance_overview import ParticipantOverviewDataFinanceOverview
from empire_platform_api_public_client.models.participant_overview_data_organisation_members import ParticipantOverviewDataOrganisationMembers
from empire_platform_api_public_client.models.permission import Permission
from empire_platform_api_public_client.models.platform_appearance import PlatformAppearance
from empire_platform_api_public_client.models.profile import Profile
from empire_platform_api_public_client.models.profile_details import ProfileDetails
from empire_platform_api_public_client.models.profile_user import ProfileUser
from empire_platform_api_public_client.models.profile_user_organisation import ProfileUserOrganisation
from empire_platform_api_public_client.models.public_aggregated_nominations_overview_response import PublicAggregatedNominationsOverviewResponse
from empire_platform_api_public_client.models.public_aggregated_nominations_overview_response_mtus_inner import PublicAggregatedNominationsOverviewResponseMtusInner
from empire_platform_api_public_client.models.public_aggregated_nominations_overview_response_mtus_inner_values_inner import PublicAggregatedNominationsOverviewResponseMtusInnerValuesInner
from empire_platform_api_public_client.models.public_auction import PublicAuction
from empire_platform_api_public_client.models.public_auction_batch import PublicAuctionBatch
from empire_platform_api_public_client.models.public_auction_bid_status import PublicAuctionBidStatus
from empire_platform_api_public_client.models.public_auction_status import PublicAuctionStatus
from empire_platform_api_public_client.models.public_day_ahead_auction import PublicDayAheadAuction
from empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_mtu_results import PublicDayAheadOrIntraDayAuctionMtuResults
from empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_mtu_results_bids_inner import PublicDayAheadOrIntraDayAuctionMtuResultsBidsInner
from empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_results import PublicDayAheadOrIntraDayAuctionResults
from empire_platform_api_public_client.models.public_intra_day_auction import PublicIntraDayAuction
from empire_platform_api_public_client.models.public_long_term_auction import PublicLongTermAuction
from empire_platform_api_public_client.models.public_long_term_auction_results import PublicLongTermAuctionResults
from empire_platform_api_public_client.models.purchased_by_organisation import PurchasedByOrganisation
from empire_platform_api_public_client.models.reserve_price_publish_type import ReservePricePublishType
from empire_platform_api_public_client.models.return_auction import ReturnAuction
from empire_platform_api_public_client.models.sage_code import SageCode
from empire_platform_api_public_client.models.secondary_market_capacity_price_mtu import SecondaryMarketCapacityPriceMtu
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry import SecondaryMarketDayAheadOrIntraDayNoticeboardEntry
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_details import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryDetails
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_matching import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response_mtus_inner import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponseMtusInner
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_options import SecondaryMarketDayAheadOrIntraDayNoticeboardOptions
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_response_options import SecondaryMarketDayAheadOrIntraDayNoticeboardResponseOptions
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_transfer_request import SecondaryMarketDayAheadOrIntraDayTransferRequest
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_transfer_request_mtus_inner import SecondaryMarketDayAheadOrIntraDayTransferRequestMtusInner
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_transfer_request_options import SecondaryMarketDayAheadOrIntraDayTransferRequestOptions
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_transfer_request_options_mtus_inner import SecondaryMarketDayAheadOrIntraDayTransferRequestOptionsMtusInner
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_entry import SecondaryMarketLongTermNoticeboardEntry
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_entry_details import SecondaryMarketLongTermNoticeboardEntryDetails
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_entry_response import SecondaryMarketLongTermNoticeboardEntryResponse
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_options import SecondaryMarketLongTermNoticeboardOptions
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_response_options import SecondaryMarketLongTermNoticeboardResponseOptions
from empire_platform_api_public_client.models.secondary_market_long_term_transfer_request_options import SecondaryMarketLongTermTransferRequestOptions
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry import SecondaryMarketNoticeboardEntry
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry_batch import SecondaryMarketNoticeboardEntryBatch
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry_status import SecondaryMarketNoticeboardEntryStatus
from empire_platform_api_public_client.models.secondary_market_return_request import SecondaryMarketReturnRequest
from empire_platform_api_public_client.models.secondary_market_return_request_batch import SecondaryMarketReturnRequestBatch
from empire_platform_api_public_client.models.secondary_market_return_request_status import SecondaryMarketReturnRequestStatus
from empire_platform_api_public_client.models.secondary_market_transfer_request import SecondaryMarketTransferRequest
from empire_platform_api_public_client.models.secondary_market_transfer_request_batch import SecondaryMarketTransferRequestBatch
from empire_platform_api_public_client.models.secondary_market_transfer_request_status import SecondaryMarketTransferRequestStatus
from empire_platform_api_public_client.models.secondary_market_transfer_request_type import SecondaryMarketTransferRequestType
from empire_platform_api_public_client.models.secondary_market_transfer_transmission_rights_mtu import SecondaryMarketTransferTransmissionRightsMtu
from empire_platform_api_public_client.models.settlement import Settlement
from empire_platform_api_public_client.models.settlement_item import SettlementItem
from empire_platform_api_public_client.models.settlement_per_source import SettlementPerSource
from empire_platform_api_public_client.models.settlement_source_type import SettlementSourceType
from empire_platform_api_public_client.models.settlement_sub_source_type import SettlementSubSourceType
from empire_platform_api_public_client.models.source_auction import SourceAuction
from empire_platform_api_public_client.models.source_auction_display_data import SourceAuctionDisplayData
from empire_platform_api_public_client.models.source_auction_result import SourceAuctionResult
from empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request import SubmitDayAheadOrIntraDayBidsRequest
from empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request_bid_groups_inner import SubmitDayAheadOrIntraDayBidsRequestBidGroupsInner
from empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request_bid_groups_inner_bids_inner import SubmitDayAheadOrIntraDayBidsRequestBidGroupsInnerBidsInner
from empire_platform_api_public_client.models.submit_long_term_bids_request import SubmitLongTermBidsRequest
from empire_platform_api_public_client.models.submit_long_term_bids_request_bids_inner import SubmitLongTermBidsRequestBidsInner
from empire_platform_api_public_client.models.submit_nominations_mtu import SubmitNominationsMtu
from empire_platform_api_public_client.models.submit_timescale_nominations_request import SubmitTimescaleNominationsRequest
from empire_platform_api_public_client.models.system_message_category import SystemMessageCategory
from empire_platform_api_public_client.models.timescale_nomination_mtu_status import TimescaleNominationMtuStatus
from empire_platform_api_public_client.models.timescale_nomination_options import TimescaleNominationOptions
from empire_platform_api_public_client.models.timescale_nomination_options_window_timing import TimescaleNominationOptionsWindowTiming
from empire_platform_api_public_client.models.timescale_nomination_status import TimescaleNominationStatus
from empire_platform_api_public_client.models.timescale_nomination_type import TimescaleNominationType
from empire_platform_api_public_client.models.timescale_nomination_window_status import TimescaleNominationWindowStatus
from empire_platform_api_public_client.models.timescale_nominations import TimescaleNominations
from empire_platform_api_public_client.models.timescale_nominations_mtus_inner import TimescaleNominationsMtusInner
from empire_platform_api_public_client.models.timescale_nominations_mtus_inner_current_nomination import TimescaleNominationsMtusInnerCurrentNomination
from empire_platform_api_public_client.models.transmission_rights_overview import TransmissionRightsOverview
from empire_platform_api_public_client.models.transmission_rights_overview_mtus_inner import TransmissionRightsOverviewMtusInner
from empire_platform_api_public_client.models.transmission_rights_overview_mtus_inner_values_inner import TransmissionRightsOverviewMtusInnerValuesInner
from empire_platform_api_public_client.models.transmission_rights_overview_mtus_inner_values_inner_timescales_inner import TransmissionRightsOverviewMtusInnerValuesInnerTimescalesInner
from empire_platform_api_public_client.models.uiosi_not_resold import UiosiNotResold
from empire_platform_api_public_client.models.uiosi_overview import UiosiOverview
from empire_platform_api_public_client.models.uiosi_overview_per_mtu import UiosiOverviewPerMtu
from empire_platform_api_public_client.models.uiosi_resold import UiosiResold
from empire_platform_api_public_client.models.unread_messages_response import UnreadMessagesResponse
from empire_platform_api_public_client.models.update_day_ahead_or_intra_day_default_bid_request import UpdateDayAheadOrIntraDayDefaultBidRequest
from empire_platform_api_public_client.models.update_default_nomination_request import UpdateDefaultNominationRequest
from empire_platform_api_public_client.models.update_long_term_default_bid_request import UpdateLongTermDefaultBidRequest
from empire_platform_api_public_client.models.update_profile_details_request import UpdateProfileDetailsRequest
from empire_platform_api_public_client.models.update_user_request import UpdateUserRequest
from empire_platform_api_public_client.models.user import User
from empire_platform_api_public_client.models.user_organisation import UserOrganisation
from empire_platform_api_public_client.models.user_preferences import UserPreferences
from empire_platform_api_public_client.models.user_preferences_general_notifications import UserPreferencesGeneralNotifications
from empire_platform_api_public_client.models.user_preferences_subscription_notifications import UserPreferencesSubscriptionNotifications
from empire_platform_api_public_client.models.user_role import UserRole
from empire_platform_api_public_client.models.user_status import UserStatus
from empire_platform_api_public_client.models.vat_rate_type import VatRateType
from empire_platform_api_public_client.models.version import Version
from empire_platform_api_public_client.models.zendesk_chat_token_response import ZendeskChatTokenResponse
