# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.long_term_auction_bid_sort_by import LongTermAuctionBidSortBy  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestLongTermAuctionBidSortBy(unittest.TestCase):
    """LongTermAuctionBidSortBy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLongTermAuctionBidSortBy(self):
        """Test LongTermAuctionBidSortBy"""
        # inst = LongTermAuctionBidSortBy()

if __name__ == '__main__':
    unittest.main()
