# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.message import Message  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestMessage(unittest.TestCase):
    """Message unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Message
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Message`
        """
        model = empire_platform_api_public_client.models.message.Message()  # noqa: E501
        if include_optional :
            return Message(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                received_at = '2022-01-04T00:00Z', 
                category = 'GENERAL', 
                sender = 'ICO', 
                severity = 'CRITICAL_ALERT', 
                type = 'AUCTION', 
                subject = '', 
                body = '', 
                read = True, 
                entity_id = '', 
                attachment = empire_platform_api_public_client.models.attachment.Attachment(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    file_name = '', 
                    file_size = 0, 
                    mime_type = '', 
                    url = '', )
            )
        else :
            return Message(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                received_at = '2022-01-04T00:00Z',
                category = 'GENERAL',
                sender = 'ICO',
                severity = 'CRITICAL_ALERT',
                type = 'AUCTION',
                subject = '',
                body = '',
        )
        """

    def testMessage(self):
        """Test Message"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
