# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from empire_platform_api_public_client.models.manual_file_upload_request import ManualFileUploadRequest

from empire_platform_api_public_client.api_client import ApiClient
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ManualFileUploadApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def upload_day_ahead_or_intra_day_bids(self, manual_file_upload_request : ManualFileUploadRequest, **kwargs) -> None:  # noqa: E501
        """upload_day_ahead_or_intra_day_bids  # noqa: E501

        Upload Bids as a Participant for Day Ahead or Intra-Day Auction as a \"Bid Document\", read more at: https://eepublicdownloads.entsoe.eu/clean-documents/EDI/Library/cim_based/schema/Bid_document_UML_model_and_schema_v1.1.pdf  First you need to upload the \"Bid Document\" XML as a standard Attachment using the `uploadAttachment` endpoint, then you need to submit the returned ID of the Attachment to this endpoint, which validates file syntax and contents before accepting it.  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_BIDS`   * `MANAGE_ANY_MANUAL_FILE_UPLOAD`  __Generates Audit Log Entry:__ `UPLOAD_DAY_AHEAD_OR_INTRA_DAY_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_day_ahead_or_intra_day_bids(manual_file_upload_request, async_req=True)
        >>> result = thread.get()

        :param manual_file_upload_request: (required)
        :type manual_file_upload_request: ManualFileUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the upload_day_ahead_or_intra_day_bids_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.upload_day_ahead_or_intra_day_bids_with_http_info(manual_file_upload_request, **kwargs)  # noqa: E501

    @validate_arguments
    def upload_day_ahead_or_intra_day_bids_with_http_info(self, manual_file_upload_request : ManualFileUploadRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """upload_day_ahead_or_intra_day_bids  # noqa: E501

        Upload Bids as a Participant for Day Ahead or Intra-Day Auction as a \"Bid Document\", read more at: https://eepublicdownloads.entsoe.eu/clean-documents/EDI/Library/cim_based/schema/Bid_document_UML_model_and_schema_v1.1.pdf  First you need to upload the \"Bid Document\" XML as a standard Attachment using the `uploadAttachment` endpoint, then you need to submit the returned ID of the Attachment to this endpoint, which validates file syntax and contents before accepting it.  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_BIDS`   * `MANAGE_ANY_MANUAL_FILE_UPLOAD`  __Generates Audit Log Entry:__ `UPLOAD_DAY_AHEAD_OR_INTRA_DAY_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_day_ahead_or_intra_day_bids_with_http_info(manual_file_upload_request, async_req=True)
        >>> result = thread.get()

        :param manual_file_upload_request: (required)
        :type manual_file_upload_request: ManualFileUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'manual_file_upload_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_day_ahead_or_intra_day_bids" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['manual_file_upload_request'] is not None:
            _body_params = _params['manual_file_upload_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/manual-file-upload/bids/day-ahead-or-intra-day', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def upload_long_term_bids(self, manual_file_upload_request : ManualFileUploadRequest, **kwargs) -> None:  # noqa: E501
        """upload_long_term_bids  # noqa: E501

        Upload bids as a Participant for a Long Term Auction as a \"Bid Document\", read more at: https://eepublicdownloads.entsoe.eu/clean-documents/EDI/Library/cim_based/schema/Bid_document_UML_model_and_schema_v1.1.pdf  First you need to upload the \"Bid Document\" XML as a standard Attachment using the `uploadAttachment` endpoint, then you need to submit the returned ID of the Attachment to this endpoint, which validates file syntax and contents before accepting it.  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_BIDS`   * `MANAGE_ANY_MANUAL_FILE_UPLOAD`  __Generates Audit Log Entry:__ `UPLOAD_LONG_TERM_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_long_term_bids(manual_file_upload_request, async_req=True)
        >>> result = thread.get()

        :param manual_file_upload_request: (required)
        :type manual_file_upload_request: ManualFileUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the upload_long_term_bids_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.upload_long_term_bids_with_http_info(manual_file_upload_request, **kwargs)  # noqa: E501

    @validate_arguments
    def upload_long_term_bids_with_http_info(self, manual_file_upload_request : ManualFileUploadRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """upload_long_term_bids  # noqa: E501

        Upload bids as a Participant for a Long Term Auction as a \"Bid Document\", read more at: https://eepublicdownloads.entsoe.eu/clean-documents/EDI/Library/cim_based/schema/Bid_document_UML_model_and_schema_v1.1.pdf  First you need to upload the \"Bid Document\" XML as a standard Attachment using the `uploadAttachment` endpoint, then you need to submit the returned ID of the Attachment to this endpoint, which validates file syntax and contents before accepting it.  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_BIDS`   * `MANAGE_ANY_MANUAL_FILE_UPLOAD`  __Generates Audit Log Entry:__ `UPLOAD_LONG_TERM_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_long_term_bids_with_http_info(manual_file_upload_request, async_req=True)
        >>> result = thread.get()

        :param manual_file_upload_request: (required)
        :type manual_file_upload_request: ManualFileUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'manual_file_upload_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_long_term_bids" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['manual_file_upload_request'] is not None:
            _body_params = _params['manual_file_upload_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/manual-file-upload/bids/long-term', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def upload_timescale_nominations(self, manual_file_upload_request : ManualFileUploadRequest, **kwargs) -> None:  # noqa: E501
        """upload_timescale_nominations  # noqa: E501

        Upload Timescale Nominations for Participant as a \"Schedule Document\", read more at: https://eepublicdownloads.entsoe.eu/clean-documents/EDI/Library/cim_based/schema/Schedule%20document%20uml%20model%20and%20schema%20v1.1.pdf  First you need to upload the \"Schedule Document\" XML as a standard Attachment using the `uploadAttachment` endpoint, then you need to submit the returned ID of the Attachment to this endpoint, which validates file syntax and contents before accepting it.  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_NOMINATIONS`   * `MANAGE_ANY_MANUAL_FILE_UPLOAD`  __Generates Audit Log Entry:__ `UPLOAD_TIMESCALE_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_timescale_nominations(manual_file_upload_request, async_req=True)
        >>> result = thread.get()

        :param manual_file_upload_request: (required)
        :type manual_file_upload_request: ManualFileUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the upload_timescale_nominations_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.upload_timescale_nominations_with_http_info(manual_file_upload_request, **kwargs)  # noqa: E501

    @validate_arguments
    def upload_timescale_nominations_with_http_info(self, manual_file_upload_request : ManualFileUploadRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """upload_timescale_nominations  # noqa: E501

        Upload Timescale Nominations for Participant as a \"Schedule Document\", read more at: https://eepublicdownloads.entsoe.eu/clean-documents/EDI/Library/cim_based/schema/Schedule%20document%20uml%20model%20and%20schema%20v1.1.pdf  First you need to upload the \"Schedule Document\" XML as a standard Attachment using the `uploadAttachment` endpoint, then you need to submit the returned ID of the Attachment to this endpoint, which validates file syntax and contents before accepting it.  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_NOMINATIONS`   * `MANAGE_ANY_MANUAL_FILE_UPLOAD`  __Generates Audit Log Entry:__ `UPLOAD_TIMESCALE_NOMINATIONS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_timescale_nominations_with_http_info(manual_file_upload_request, async_req=True)
        >>> result = thread.get()

        :param manual_file_upload_request: (required)
        :type manual_file_upload_request: ManualFileUploadRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'manual_file_upload_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_timescale_nominations" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['manual_file_upload_request'] is not None:
            _body_params = _params['manual_file_upload_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/manual-file-upload/nominations/timescale', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))
