# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.public_long_term_auction_results import PublicLongTermAuctionResults  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestPublicLongTermAuctionResults(unittest.TestCase):
    """PublicLongTermAuctionResults unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PublicLongTermAuctionResults
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PublicLongTermAuctionResults`
        """
        model = empire_platform_api_public_client.models.public_long_term_auction_results.PublicLongTermAuctionResults()  # noqa: E501
        if include_optional :
            return PublicLongTermAuctionResults(
                bids = [
                    empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_mtu_results_bids_inner.PublicDayAheadOrIntraDayAuctionMtuResults_bids_inner(
                        value = empire_platform_api_public_client.models.bid_value.BidValue(
                            price = 1.337, 
                            capacity = 56, ), 
                        allocated_capacity = 56, 
                        status = 'SUCCESSFUL', )
                    ], 
                successful_participants = [
                    empire_platform_api_public_client.models.auction_result_participant.AuctionResultParticipant(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', 
                        eic_code = '---7S--058SL--92', )
                    ], 
                marginal_price = 1.337, 
                reserve_price = 1.337
            )
        else :
            return PublicLongTermAuctionResults(
                bids = [
                    empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_mtu_results_bids_inner.PublicDayAheadOrIntraDayAuctionMtuResults_bids_inner(
                        value = empire_platform_api_public_client.models.bid_value.BidValue(
                            price = 1.337, 
                            capacity = 56, ), 
                        allocated_capacity = 56, 
                        status = 'SUCCESSFUL', )
                    ],
                successful_participants = [
                    empire_platform_api_public_client.models.auction_result_participant.AuctionResultParticipant(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', 
                        eic_code = '---7S--058SL--92', )
                    ],
                marginal_price = 1.337,
        )
        """

    def testPublicLongTermAuctionResults(self):
        """Test PublicLongTermAuctionResults"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
