# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuditLogType(str, Enum):
    """
    AuditLogType
    """

    """
    allowed enum values
    """
    CREATE_LONG_TERM_AUCTION = 'CREATE_LONG_TERM_AUCTION'
    CREATE_DAY_AHEAD_AUCTION = 'CREATE_DAY_AHEAD_AUCTION'
    CREATE_INTRA_DAY_AUCTION = 'CREATE_INTRA_DAY_AUCTION'
    UPDATE_LONG_TERM_AUCTION = 'UPDATE_LONG_TERM_AUCTION'
    UPDATE_DAY_AHEAD_AUCTION = 'UPDATE_DAY_AHEAD_AUCTION'
    UPDATE_INTRA_DAY_AUCTION = 'UPDATE_INTRA_DAY_AUCTION'
    DELETE_AUCTION = 'DELETE_AUCTION'
    CANCEL_AUCTION = 'CANCEL_AUCTION'
    SUBMIT_LONG_TERM_BIDS = 'SUBMIT_LONG_TERM_BIDS'
    SUBMIT_DAY_AHEAD_OR_INTRA_DAY_BIDS = 'SUBMIT_DAY_AHEAD_OR_INTRA_DAY_BIDS'
    UPDATE_LONG_TERM_AUCTION_DEFAULT = 'UPDATE_LONG_TERM_AUCTION_DEFAULT'
    UPDATE_DAY_AHEAD_OR_INTRA_DAY_AUCTION_DEFAULT = 'UPDATE_DAY_AHEAD_OR_INTRA_DAY_AUCTION_DEFAULT'
    SUBMIT_NTC_OVERRIDE = 'SUBMIT_NTC_OVERRIDE'
    CREATE_NTC_REDUCTION = 'CREATE_NTC_REDUCTION'
    UPDATE_NTC_REDUCTION = 'UPDATE_NTC_REDUCTION'
    DELETE_NTC_REDUCTION = 'DELETE_NTC_REDUCTION'
    CREATE_NTC_ADDITION = 'CREATE_NTC_ADDITION'
    UPDATE_NTC_ADDITION = 'UPDATE_NTC_ADDITION'
    DELETE_NTC_ADDITION = 'DELETE_NTC_ADDITION'
    CREATE_UNPLANNED_OUTAGE = 'CREATE_UNPLANNED_OUTAGE'
    UPDATE_UNPLANNED_OUTAGE = 'UPDATE_UNPLANNED_OUTAGE'
    CANCEL_UNPLANNED_OUTAGE = 'CANCEL_UNPLANNED_OUTAGE'
    END_UNPLANNED_OUTAGE = 'END_UNPLANNED_OUTAGE'
    CREATE_PLANNED_OUTAGE = 'CREATE_PLANNED_OUTAGE'
    UPDATE_PLANNED_OUTAGE = 'UPDATE_PLANNED_OUTAGE'
    DELETE_PLANNED_OUTAGE = 'DELETE_PLANNED_OUTAGE'
    CANCEL_PLANNED_OUTAGE = 'CANCEL_PLANNED_OUTAGE'
    SUBMIT_TIMESCALE_NOMINATIONS = 'SUBMIT_TIMESCALE_NOMINATIONS'
    SUBMIT_SOSO_NOMINATIONS = 'SUBMIT_SOSO_NOMINATIONS'
    SUBMIT_BPP_NOMINATIONS = 'SUBMIT_BPP_NOMINATIONS'
    CREATE_LONG_TERM_DEFAULT_BID = 'CREATE_LONG_TERM_DEFAULT_BID'
    CREATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID = 'CREATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID'
    UPDATE_LONG_TERM_DEFAULT_BID = 'UPDATE_LONG_TERM_DEFAULT_BID'
    UPDATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID = 'UPDATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID'
    DELETE_DEFAULT_BID = 'DELETE_DEFAULT_BID'
    CREATE_DEFAULT_NOMINATION = 'CREATE_DEFAULT_NOMINATION'
    UPDATE_DEFAULT_NOMINATION = 'UPDATE_DEFAULT_NOMINATION'
    DELETE_DEFAULT_NOMINATION = 'DELETE_DEFAULT_NOMINATION'
    CREATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOW_OVERRIDE = 'CREATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOW_OVERRIDE'
    CREATE_INTRA_DAY_NOMINATION_WINDOW_OVERRIDE = 'CREATE_INTRA_DAY_NOMINATION_WINDOW_OVERRIDE'
    UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOW_OVERRIDE = 'UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOW_OVERRIDE'
    UPDATE_INTRA_DAY_NOMINATION_WINDOW_OVERRIDE = 'UPDATE_INTRA_DAY_NOMINATION_WINDOW_OVERRIDE'
    RESEND_CRISIS_REMIT = 'RESEND_CRISIS_REMIT'
    BYPASS_CRISIS_REMIT = 'BYPASS_CRISIS_REMIT'
    COMPLETE_CRISIS_STATIC_TASK = 'COMPLETE_CRISIS_STATIC_TASK'
    CANCEL_CRISIS_AUCTION = 'CANCEL_CRISIS_AUCTION'
    DISMISS_CRISIS_AUCTION = 'DISMISS_CRISIS_AUCTION'
    EXECUTE_CRISIS_CURTAILMENT = 'EXECUTE_CRISIS_CURTAILMENT'
    DISMISS_CRISIS_CURTAILMENT = 'DISMISS_CRISIS_CURTAILMENT'
    DISMISS_CRISIS_BPP = 'DISMISS_CRISIS_BPP'
    POST_CRISIS_PARTICIPANT_MESSAGE = 'POST_CRISIS_PARTICIPANT_MESSAGE'
    UPLOAD_ATTACHMENT = 'UPLOAD_ATTACHMENT'
    CREATE_PARTICIPANT_ORGANISATION = 'CREATE_PARTICIPANT_ORGANISATION'
    UPDATE_PARTICIPANT_ORGANISATION = 'UPDATE_PARTICIPANT_ORGANISATION'
    UPDATE_USER = 'UPDATE_USER'
    INVITE_USER = 'INVITE_USER'
    BULK_INVITE_USERS = 'BULK_INVITE_USERS'
    RESEND_USER_INVITE = 'RESEND_USER_INVITE'
    REVOKE_USER_INVITE = 'REVOKE_USER_INVITE'
    SUSPEND_USER = 'SUSPEND_USER'
    UNSUSPEND_USER = 'UNSUSPEND_USER'
    IMPERSONATE_USER = 'IMPERSONATE_USER'
    UPDATE_PROFILE_DETAILS = 'UPDATE_PROFILE_DETAILS'
    UPDATE_PREFERENCES = 'UPDATE_PREFERENCES'
    CREATE_API_KEY = 'CREATE_API_KEY'
    DELETE_API_KEY = 'DELETE_API_KEY'
    UPDATE_BIDDING_CONFIGURATION = 'UPDATE_BIDDING_CONFIGURATION'
    CREATE_ORGANISATION_DOCUMENT = 'CREATE_ORGANISATION_DOCUMENT'
    DELETE_ORGANISATION_DOCUMENT = 'DELETE_ORGANISATION_DOCUMENT'
    SUBMIT_BPP_PURCHASE_FORM = 'SUBMIT_BPP_PURCHASE_FORM'
    SET_BPP_SUBMISSION_STATUS = 'SET_BPP_SUBMISSION_STATUS'
    RESUBMIT_BPP_SUBMISSION = 'RESUBMIT_BPP_SUBMISSION'
    CREATE_DAY_AHEAD_BUY_NOW_OFFERS = 'CREATE_DAY_AHEAD_BUY_NOW_OFFERS'
    CREATE_INTRA_DAY_BUY_NOW_OFFERS = 'CREATE_INTRA_DAY_BUY_NOW_OFFERS'
    PURCHASE_BUY_NOW_OFFER = 'PURCHASE_BUY_NOW_OFFER'
    DELETE_BUY_NOW_OFFER = 'DELETE_BUY_NOW_OFFER'
    DELETE_DAY_AHEAD_BUY_NOW_OFFERS = 'DELETE_DAY_AHEAD_BUY_NOW_OFFERS'
    DELETE_INTRA_DAY_BUY_NOW_OFFERS = 'DELETE_INTRA_DAY_BUY_NOW_OFFERS'
    CREATE_SECONDARY_MARKET_RETURN_REQUEST = 'CREATE_SECONDARY_MARKET_RETURN_REQUEST'
    WITHDRAW_SECONDARY_MARKET_RETURN_REQUEST = 'WITHDRAW_SECONDARY_MARKET_RETURN_REQUEST'
    REJECT_SECONDARY_MARKET_TRANSFER_REQUEST = 'REJECT_SECONDARY_MARKET_TRANSFER_REQUEST'
    ACCEPT_SECONDARY_MARKET_TRANSFER_REQUEST = 'ACCEPT_SECONDARY_MARKET_TRANSFER_REQUEST'
    WITHDRAW_SECONDARY_MARKET_TRANSFER_REQUEST = 'WITHDRAW_SECONDARY_MARKET_TRANSFER_REQUEST'
    CREATE_LT_SECONDARY_MARKET_TRANSFER_REQUEST = 'CREATE_LT_SECONDARY_MARKET_TRANSFER_REQUEST'
    CREATE_DA_OR_ID_SECONDARY_MARKET_TRANSFER_REQUEST = 'CREATE_DA_OR_ID_SECONDARY_MARKET_TRANSFER_REQUEST'
    CREATE_LT_SECONDARY_MARKET_NOTICEBOARD_ENTRY = 'CREATE_LT_SECONDARY_MARKET_NOTICEBOARD_ENTRY'
    CREATE_DA_OR_ID_SECONDARY_MARKET_NOTICEBOARD_ENTRY = 'CREATE_DA_OR_ID_SECONDARY_MARKET_NOTICEBOARD_ENTRY'
    CREATE_LT_SECONDARY_MARKET_NOTICEBOARD_RESPONSE = 'CREATE_LT_SECONDARY_MARKET_NOTICEBOARD_RESPONSE'
    CREATE_DA_OR_ID_SECONDARY_MARKET_NOTICEBOARD_RESPONSE = 'CREATE_DA_OR_ID_SECONDARY_MARKET_NOTICEBOARD_RESPONSE'
    DELETE_SECONDARY_MARKET_NOTICEBOARD_ENTRY = 'DELETE_SECONDARY_MARKET_NOTICEBOARD_ENTRY'
    UPLOAD_LONG_TERM_BIDS = 'UPLOAD_LONG_TERM_BIDS'
    UPLOAD_DAY_AHEAD_OR_INTRA_DAY_BIDS = 'UPLOAD_DAY_AHEAD_OR_INTRA_DAY_BIDS'
    UPLOAD_TIMESCALE_NOMINATIONS = 'UPLOAD_TIMESCALE_NOMINATIONS'
    UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOWS_BUSINESS_SETTINGS = 'UPDATE_LONG_TERM_OR_DAY_AHEAD_NOMINATION_WINDOWS_BUSINESS_SETTINGS'
    UPDATE_INTRA_DAY_NOMINATION_WINDOWS_BUSINESS_SETTINGS = 'UPDATE_INTRA_DAY_NOMINATION_WINDOWS_BUSINESS_SETTINGS'
    UPDATE_REALLOCATION_PRINCIPLES_BUSINESS_SETTINGS = 'UPDATE_REALLOCATION_PRINCIPLES_BUSINESS_SETTINGS'
    UPDATE_FINANCE_BUSINESS_SETTINGS = 'UPDATE_FINANCE_BUSINESS_SETTINGS'
    INIT_FINANCE_SAGE_AUTH = 'INIT_FINANCE_SAGE_AUTH'
    UPDATE_BPP_PROVIDER_BUSINESS_SETTINGS = 'UPDATE_BPP_PROVIDER_BUSINESS_SETTINGS'
    SEND_FINANCE_INVOICE = 'SEND_FINANCE_INVOICE'
    RESEND_FINANCE_INVOICE = 'RESEND_FINANCE_INVOICE'
    MARK_PAID_FINANCE_INVOICE = 'MARK_PAID_FINANCE_INVOICE'
    SUBMIT_FINANCE_MANUAL_ITEMS_INVOICE = 'SUBMIT_FINANCE_MANUAL_ITEMS_INVOICE'
    MANUAL_START_BUSINESS_PROCESS_WORKFLOW = 'MANUAL_START_BUSINESS_PROCESS_WORKFLOW'
    RESOLVE_BUSINESS_PROCESS_STEP = 'RESOLVE_BUSINESS_PROCESS_STEP'
    RE_RUN_BUSINESS_PROCESS_STEP = 'RE_RUN_BUSINESS_PROCESS_STEP'
    PROCESS_DATA_FLOW_VERSION = 'PROCESS_DATA_FLOW_VERSION'
    CREATE_DATA_FLOW = 'CREATE_DATA_FLOW'
    UPDATE_DATA_FLOW = 'UPDATE_DATA_FLOW'
    UPDATE_FINANCE_INFORMATION = 'UPDATE_FINANCE_INFORMATION'

    @classmethod
    def from_json(cls, json_str: str) -> AuditLogType:
        """Create an instance of AuditLogType from a JSON string"""
        return AuditLogType(json.loads(json_str))


